package org.tbasket

import org.tbasket.api.Endpoint

import java.util.Properties

object EndpointSetup {

    final val EndpointUrl = "endpoint.url"
    final val EndpointUrlDefault = s"localhost:48485"

    def setupEndpoint(): Endpoint = {
        println("Initializing API endpoint...")
        val endpoint = createEndpoint()

        endpoint
    }

    private def createEndpoint(): Endpoint = {
        val properties = new Properties()
        val in         = getClass.getClassLoader.getResourceAsStream("server.properties")
        properties.load(in)
        val (url, port) = properties
                .getProperty(EndpointUrl, EndpointUrlDefault) match {
            case s"$ip:$port/$endpointPath" => (ip + "/" + endpointPath, port.toInt)
            case s"$ip:$port"               => (ip, port.toInt)
            case v                          => throw new InternalBasketServerException(s"$EndpointUrl property value is wrong: $v must be <ip>:<port>/[endpointPath]")
        }
        new Endpoint(url, port)
    }

}
